@@ -15,12 +15,30 @@
 #ifndef UMUX_H_
 #define UMUX_H_
 
-#include "unitary_calculator_basic.h"
-namespace qsim {
-namespace unitary {
-  template <typename For>
-  using UnitaryCalculator = UnitaryCalculatorBasic<For>;
-}  // namespace unitary
-}  // namepsace qsim
+#ifdef __AVX2__
+# include "unitary_calculator_avx.h"
+  namespace qsim {
+  namespace unitary {
+    template <typename For>
+    using UnitaryCalculator = UnitaryCalculatorAVX<For>;
+  }
+  }
+#elif __SSE4_1__
+# include "unitary_calculator_sse.h"
+  namespace qsim {
+  namespace unitary {
+    template <typename For>
+    using UnitaryCalculator = UnitaryCalculatorSSE<For>;
+  }
+  }
+#else
+# include "unitary_calculator_basic.h"
+  namespace qsim {
+  namespace unitary {
+    template <typename For>
+    using UnitaryCalculator = UnitaryCalculatorBasic<For>;
+  }
+  }
+#endif
 
 #endif  // UMUX_H_
